@@ -129,8 +129,11 @@ Group by StressVowel) AS averages""",[self.pk])
     def analyze(self,form):
         words = WordToken.objects.select_related('WordType','Dialog','Dialog__Speaker').filter(Dialog__Speaker=self)
         words = words.filter(WordType__CVSkel='CVC')
-        words = words.filter(WordType__Label__in = GOOD_WORDS).order_by('Dialog')
+        words = words.filter(WordType__Label__in = GOOD_WORDS)
         allout = []
+        print(str(self))
+        print("\n")
+        print(len(words))
         for w in words:
             if not w.isAcceptable():
                 continue
@@ -977,7 +980,7 @@ class WordToken(models.Model):
             outline['PhonoStatsSPhoneProb'],outline['PhonoStatsBiPhoneProb'] = getPhonotacticProb(self.WordType.getStrUR(),use_blick=False,no_stress=True)
         if form['prev_sem_pred']:
             outline['PrevSemPred'] = self.getPrevSemPred()
-            outline['ImmedSemPred'] = self.getImmediateSemPred()
+            #outline['ImmedSemPred'] = self.getImmediateSemPred()
         if form['foll_sem_pred']:
             outline['FollSemPred'] = self.getFollSemPred()
         if form['placeInDialog']:
