@@ -84,14 +84,18 @@ def combineResults(allout):
 
 @task()
 def AnalyzeSpeaker(speaker,form):
+    logger.info("Begin analysis of %s" % str(speaker))
+    logger.info("Process %s" % str(os.getpid()))
     #return speaker.analyze(form)
     out = speaker.analyze(form)
+    logger.info("Got lines for %s" % str(speaker))
     with open(fetch_media_resource("Results/Buckeye/"+str(speaker)+".txt"),'w') as f:
         f.write("\t".join(out[0].keys()))
         f.write("\n")
         for l in out:
             f.write("\t".join(map(str,l.values())))
             f.write("\n")
+    logger.info("Completed analysis of %s" % str(speaker))
 
 @task()
 def doBasicAnalysis(form):
